@@ -141,6 +141,10 @@ CentralWidget::newGame()
     {
         scorePanel_->hide();
         btUndo_->hide();
+        if (mode.first == 0)
+            btUndo_->show();
+        else
+            btUndo_->hide();
     }
     btUndo_->setEnabled(false);
 }//newGame
