@@ -11,6 +11,7 @@
 enum P2PSTATE {WAIT_SERVER_VERSION, WAIT_CLIENT_VERSION, WAIT_SERVER_NEW_GAME, RUNNING, SERVER_PAUSED, CLIENT_PAUSED};
 
 class QGridLayout;
+class QPushButton;
 class QVBoxLayout;
 class QTcpServer;
 class QTcpSocket;
@@ -36,6 +37,7 @@ private:
 private:
     QGridLayout *layout_;
     QVBoxLayout *infoLayout_;
+    QPushButton *btUndo_;
     QTcpServer *gameServer_;
     QTcpSocket  *gameClient_;
     QTcpSocket  *gameConnection_;
@@ -68,6 +70,7 @@ private slots:
     void slotOrientationChanged();
     void slotReadNetworkData();
     void displayP2PError(QAbstractSocket::SocketError socketError);
+    void slotEnableUndo(bool);
 };
 
 #endif // CENTRALWIDGET_H
