@@ -199,7 +199,7 @@ ReversiGame::startNextTurn()
         return;
     }
 
-    if (mode_ == 1 || mode_ == 2)
+    if (mode_ >= 0 && mode_ <= 2)
     {
         undoEnabled_ = !undoInfo_.isEmpty();
         emit enableUndo(undoEnabled_);
@@ -284,7 +284,7 @@ ReversiGame::undo()
     score_[currentPlayer_] -= changedCells_.count();
     score_[opponentPlayer_] += changedCells_.count() - 1;
 
-    if (lastStep.stepColor_ != computerColor_)
+    if (lastStep.stepColor_ != computerColor_ || mode_ == 0)
         isUndo_ = false;
 
     emit enableUndo(false);
