@@ -14,8 +14,9 @@ class PixmapsFactory
 {
 public:
     PixmapsFactory();
+    ~PixmapsFactory();
 private:
-    QPixmap chipPixmaps_[13];
+    QPixmap *chipPixmaps_[13];
 
     friend class ReversiItem;
 }; //class PixmapsFactory
