@@ -32,7 +32,7 @@ ReversiScene::ReversiScene(ReversiGame &reversiGame):
     fieldWidth_ = FIELDSIZE * cellWidth_;
     fieldHeight_ = FIELDSIZE * cellHeight_;
 
-    connect(&reversiGame_, SIGNAL(stepComplete()), SLOT(slotStepComplete()));
+    connect(&reversiGame_, SIGNAL(stepComplete(bool)), SLOT(slotStepComplete(bool)));
     connect(&reversiGame_, SIGNAL(newGame(int)), SLOT(slotNewGame(int)));
     connect(animTimer_, SIGNAL(timeout()), SLOT(slotAnimationStep()));
 }
@@ -82,7 +82,7 @@ void ReversiScene::syncBoard()
     update(0, 0, fieldWidth_, fieldHeight_);
 }
 
-void ReversiScene::slotStepComplete()
+void ReversiScene::slotStepComplete(bool isUndo)
 {
     int animStartStep;
     int i;
@@ -104,14 +104,18 @@ void ReversiScene::slotStepComplete()
     for (i = 0; i < cell_count; ++i)
         animCellStep_[i] = animStartStep;
     animFirstCell_ = animLastCell_ = 1;
-
     //set first chip
     int x = changedCells.at(0).x();
     int y = changedCells.at(0).y();
     ReversiItem *it = static_cast<ReversiItem*>(itemAt(x * cellWidth_, y * cellHeight_));
-    it->setColor(reversiGame_.opponentPlayer());
+    it->setColor(isUndo ? Empty :reversiGame_.opponentPlayer());
     update(x * cellWidth_, y * cellHeight_, cellWidth_, cellHeight_);
-
+    //temp
+    //if (isUndo)
+    //{
+    //    reversiGame_.startNextTurn();
+    //    return;
+    //}
     //start animation
     animTimer_->start(animationSpeed_);
 }//slotStepComplete
@@ -143,7 +147,7 @@ void ReversiScene::slotAnimationStep()
         animTimer_->stop();
 
         currentPlayer_ = reversiGame_.opponentPlayer();
-        for(int i = 0; i < changedCells.size(); ++i)
+        for(int i = 1; i < changedCells.size(); ++i)
         {
             int x = changedCells.at(i).x();
             int y = changedCells.at(i).y();
